==> cyklop_0.1.0.tar.gz: cyklop-0.1.0/ts/cyklop.pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AboutPage</name>
    <message>
        <location filename="../qml/cyklop/AboutPage.qml" line="41"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/AboutPage.qml" line="46"/>
        <source>A bicycle sharing application. It allows you to find free bikes or stations near you. It currently supports every system handled by &lt;em&gt;Nextbike&lt;/em&gt; including more than 80 cities from Germany, Austria, Latvia, Poland, Switzerland, Turkey, Azerbaijan, Cyprus, the United Arabian Emirates and New Zealand.</source>
        <translation>Aplikacja do obsługi systemu rowerów publicznych. Pozwala na znalezienie wolnych rowerów lub stacji. Obecnie działa we wszystkich systemach obsługiwanych przez firmę &lt;em&gt;Nextbike&lt;/em&gt;, czyli w ponad 80 miastach z Niemiec, Austrii, Łotwy, Polski, Szwajcarii, Turcji, Azerbejdżanu, Cypru, Zjednoczonych Emiratów Arabskich i Nowej Zelandii.</translation>
    </message>
    <message>
        <source>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum accumsan mattis lorem quis auctor. Aenean posuere orci ligula, vitae vestibulum magna. Sed nulla velit, eleifend vitae aliquam mattis, condimentum et metus.</source>
        <translation type="obsolete">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum accumsan mattis lorem quis auctor. Aenean posuere orci ligula, vitae vestibulum magna. Sed nulla velit, eleifend vitae aliquam mattis, condimentum et metus.</translation>
    </message>
</context>
<context>
    <name>BusyPane</name>
    <message>
        <location filename="../qml/cyklop/BusyPane.qml" line="8"/>
        <source>updating...</source>
        <translation>aktualizacja...</translation>
    </message>
</context>
<context>
    <name>FirstRunPage</name>
    <message>
        <location filename="../qml/cyklop/FirstRunPage.qml" line="55"/>
        <source>Select your city</source>
        <translation>Wybierz miasto</translation>
    </message>
</context>
<context>
    <name>PlacePage</name>
    <message>
        <location filename="../qml/cyklop/PlacePage.qml" line="58"/>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/PlacePage.qml" line="60"/>
        <source>free bikes</source>
        <translation>dostępnych rowerów</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/PlacePage.qml" line="62"/>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/PlacePage.qml" line="64"/>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="18"/>
        <source>Save settings</source>
        <translation>Zapisz ustawienia</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="26"/>
        <source>Restart for the change to take effect!</source>
        <translation>Ponownie uruchom aplikacje!</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="49"/>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="65"/>
        <source>GPS interval (ms)</source>
        <translation>Częstotliwość GPS</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="79"/>
        <source>Search radius (m)</source>
        <translation>Promień szukania</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="93"/>
        <source>Search timeout (ms)</source>
        <translation>Czas szukania</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/SettingsPage.qml" line="107"/>
        <source>Choose your language</source>
        <translation>Wybierz język</translation>
    </message>
</context>
<context>
    <name>SplashPane</name>
    <message>
        <location filename="../qml/cyklop/SplashPane.qml" line="76"/>
        <source>loading...</source>
        <translation>wczytywanie...</translation>
    </message>
</context>
<context>
    <name>StationsList</name>
    <message>
        <location filename="../qml/cyklop/StationsList.qml" line="85"/>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsList.qml" line="87"/>
        <source>free bikes</source>
        <translation>dostępne rowery</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsList.qml" line="89"/>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsList.qml" line="91"/>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>StationsPage</name>
    <message>
        <location filename="../qml/cyklop/StationsPage.qml" line="29"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsPage.qml" line="40"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsPage.qml" line="78"/>
        <source>Can&apos;t find stations :-(</source>
        <translation>Brak stacji w pobliżu :-(</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsPage.qml" line="112"/>
        <source>Updating data...</source>
        <translation>Aktualizacja...</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/StationsPage.qml" line="117"/>
        <source>Finding nearest stations...</source>
        <translation>Znajdywanie najbliższych stacji...</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/cyklop/main.qml" line="114"/>
        <source>Change city</source>
        <translation>Zmień miasto</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/main.qml" line="122"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/main.qml" line="130"/>
        <source>About</source>
        <translation>O Cyklopie</translation>
    </message>
    <message>
        <location filename="../qml/cyklop/main.qml" line="137"/>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
</TS>

==> cyklop_0.1.1-0.tar.gz: cyklop-0.1.1/ts/cyklop.pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AboutPage</name>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>A bicycle sharing application. It allows you to find free bikes or stations near you. It currently supports every system handled by &lt;em&gt;Nextbike&lt;/em&gt; including more than 80 cities from Germany, Austria, Latvia, Poland, Switzerland, Turkey, Azerbaijan, Cyprus, the United Arabian Emirates and New Zealand.</source>
        <translation>Aplikacja do obsługi systemu rowerów publicznych. Pozwala na znalezienie wolnych rowerów lub stacji. Obecnie działa we wszystkich systemach obsługiwanych przez firmę &lt;em&gt;Nextbike&lt;/em&gt;, czyli w ponad 80 miastach z Niemiec, Austrii, Łotwy, Polski, Szwajcarii, Turcji, Azerbejdżanu, Cypru, Zjednoczonych Emiratów Arabskich i Nowej Zelandii. W przypadku Polski, aplikacja współpracuje z warszawskim systemem Veturilo, BemowoBike, Wrocławskim Rowerem Miejskim (WRM), OpoleBike oraz z Poznańskim Rowerem Miejskim (PRM).</translation>
    </message>
</context>
<context>
    <name>BusyPane</name>
    <message>
        <source>updating...</source>
        <translation>aktualizacja...</translation>
    </message>
</context>
<context>
    <name>FirstRunPage</name>
    <message>
        <source>Select your city</source>
        <translation>Wybierz miasto</translation>
    </message>
    <message>
        <source>Updating data...</source>
        <translation>Aktualizuję dane...</translation>
    </message>
</context>
<context>
    <name>PlacePage</name>
    <message>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <source>free bikes</source>
        <translation>dostępnych rowerów</translation>
    </message>
    <message>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Save settings</source>
        <translation>Zapisz ustawienia</translation>
    </message>
    <message>
        <source>Restart for the change to take effect!</source>
        <translation>Ponownie uruchom aplikacje!</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>GPS interval (ms)</source>
        <translation>Częstotliwość GPS</translation>
    </message>
    <message>
        <source>Search radius (m)</source>
        <translation>Promień szukania</translation>
    </message>
    <message>
        <source>Search timeout (ms)</source>
        <translation type="obsolete">Czas szukania</translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation>Wybierz język</translation>
    </message>
    <message>
        <source>Enable GPS</source>
        <translation>Włącz GPS</translation>
    </message>
</context>
<context>
    <name>SplashPane</name>
    <message>
        <source>loading...</source>
        <translation>wczytywanie...</translation>
    </message>
</context>
<context>
    <name>StationsList</name>
    <message>
        <source>or more free bikes</source>
        <translation>lub więcej rowerów</translation>
    </message>
    <message>
        <source>free bikes</source>
        <translation>dostępne rowery</translation>
    </message>
    <message>
        <source>free bike</source>
        <translation>dostępny rower</translation>
    </message>
    <message>
        <source>no free bikes</source>
        <translation>brak rowerów</translation>
    </message>
</context>
<context>
    <name>StationsPage</name>
    <message>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Can&apos;t find stations :-(</source>
        <translation>Brak stacji w pobliżu :-(</translation>
    </message>
    <message>
        <source>Updating data...</source>
        <translation>Aktualizacja...</translation>
    </message>
    <message>
        <source>Finding nearest stations...</source>
        <translation>Szukam najbliższych stacji...</translation>
    </message>
    <message>
        <source>GPS is disabled!</source>
        <translation>GPS jest wyłączony!</translation>
    </message>
    <message>
        <source>Waiting for GPS...</source>
        <translation>Czekam na sygnał GPS...</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Change city</source>
        <translation>Zmień miasto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O Cyklopie</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
</TS>
